﻿using Prism.Mvvm;
using Prism.Navigation;
using Syncfusion.XForms.PopupLayout;
using Xamarin.Forms;

namespace PopupAcceptDecline.ViewModels
{
    public class ViewModelBase : BindableBase, IInitialize, INavigationAware, IDestructible
    {
        protected INavigationService NavigationService { get; private set; }

        public string Title { get; set; }


        //this is used in the DisplayAlert
        private static bool _displayAlertAcceptDecline;


        public ViewModelBase(INavigationService navigationService)
        {
            NavigationService = navigationService;
        }


        protected bool DisplayAlert(string title, string text, string acceptButtonText, string declineButtonText = null)
        {
            SfPopupLayout popupMessage = new SfPopupLayout
            {
                PopupView =
                {
                    HeaderTitle = title,
                    AcceptButtonText = acceptButtonText,
                    AcceptCommand  = new Command(() => _displayAlertAcceptDecline = true ),
                    DeclineButtonText = declineButtonText,
                    DeclineCommand = new Command( () => _displayAlertAcceptDecline = false),
                    AppearanceMode = declineButtonText == null ? AppearanceMode.OneButton : AppearanceMode.TwoButton,
                    AutoSizeMode = AutoSizeMode.Height,
                    WidthRequest = 250,
                    ShowCloseButton = false,
                    ContentTemplate = new DataTemplate(() =>
                    {
                        Label label = new Label
                        {
                            HorizontalTextAlignment = TextAlignment.Center,
                            VerticalTextAlignment = TextAlignment.Center,
                            Text = text,
                            Padding = 25
                        };
                        return label;
                    })
                }
            };

            popupMessage.Show();

            return _displayAlertAcceptDecline;
        }




        public virtual void Initialize(INavigationParameters parameters)
        {

        }

        public virtual void OnNavigatedFrom(INavigationParameters parameters)
        {

        }

        public virtual void OnNavigatedTo(INavigationParameters parameters)
        {

        }

        public virtual void Destroy()
        {

        }
    }
}
